@@ -27,5 +27,14 @@
 class ASICCD : public ASIBase
 {
     public:
-        explicit ASICCD(const ASI_CAMERA_INFO &camInfo, const std::string &cameraName);
+        explicit ASICCD(const ASI_CAMERA_INFO &camInfo, const std::string &cameraName,
+                        const std::string &serialNumber);
+    protected:
+        virtual bool ISNewText(const char *dev, const char *name, char *texts[], char *names[], int n) override;
+
+    private:
+        void loadNicknames();
+        void saveNicknames();
+        const std::string NICKNAME_FILE = "/.indi/ZWONicknames.xml";
+        std::map<std::string, std::string> mNicknames;
 };
